summaryrefslogtreecommitdiff
path: root/noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp
Side-by-side diff
Diffstat (limited to 'noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp') (more/less context) (show whitespace changes)
-rw-r--r--noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp b/noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp
index 5c937a1..5c71a0a 100644
--- a/noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp
+++ b/noncore/settings/networksettings2/bluetooth/bluetoothBNEPrun.cpp
@@ -7,4 +7,4 @@
using Opietooth2::OTGateway;
-using Opietooth2::OTPANConnection;
-using Opietooth2::PANConnectionVector;
+using Opietooth2::OTPANNetworkSetup;
+using Opietooth2::PANNetworkSetupVector;
@@ -30,3 +30,3 @@ State_t BluetoothBNEPRun::detectState( void ) {
- 1. for any PAN connection that is found if that
+ 1. for any PAN NetworkSetup that is found if that
PAN is connected.
@@ -35,6 +35,6 @@ State_t BluetoothBNEPRun::detectState( void ) {
not manage IP settings and we are called to detect
- the state we knwo that we do not have an UP connection)
+ the state we knwo that we do not have an UP NetworkSetup)
- 2. if it not connected and we allow any connection we
- are available or if that PAN connection is to a device
+ 2. if it not connected and we allow any NetworkSetup we
+ are available or if that PAN NetworkSetup is to a device
with a correct address
@@ -43,3 +43,3 @@ State_t BluetoothBNEPRun::detectState( void ) {
we do not accept any address, we are Unavailable but
- not DOWN. I.e a new connection could perhaps be created
+ not DOWN. I.e a new NetworkSetup could perhaps be created
@@ -55,11 +55,11 @@ State_t BluetoothBNEPRun::detectState( void ) {
- // if there is a PAN connection that is UP but not
+ // if there is a PAN NetworkSetup that is UP but not
// yet configured (no ifup) the we are available
- return ( hasFreePANConnection() ) ? Available : Unknown;
+ return ( hasFreePANNetworkSetup() ) ? Available : Unknown;
}
-QString BluetoothBNEPRun::setMyState( NodeCollection * NC, Action_t A, bool ) {
+QString BluetoothBNEPRun::setMyState( NetworkSetup * NC, Action_t A, bool ) {
if( A == Activate ) {
- if( hasFreePANConnection( 1 ) ) {
+ if( hasFreePANNetworkSetup( 1 ) ) {
// we have now an assignedinterface
@@ -91,3 +91,3 @@ bool BluetoothBNEPRun::handlesInterface( InterfaceInfo * I ) {
-bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
+bool BluetoothBNEPRun::hasFreePANNetworkSetup( bool Grab ) {
@@ -97,7 +97,7 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
- // load PAN connections
- OTPANConnection * C;
+ // load PAN NetworkSetups
+ OTPANNetworkSetup * C;
InterfaceInfo * Run;
InterfaceInfo * Candidate = 0; // reuse this interface
- PANConnectionVector Conns = OT->getPANConnections();
+ PANNetworkSetupVector Conns = OT->getPANNetworkSetups();
System & Sys = NSResources->system();
@@ -114,3 +114,3 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
} else {
// is this PAN connection connecting to a Peer
// we allow ?
@@ -121,3 +121,3 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
if( C->ConnectedTo == (*it) ) {
- // this is a connection we could accept
+ // this is a NetworkSetup we could accept
IsValid = 1;
@@ -137,3 +137,3 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
- // is this PAN connection available to us ?
+ // is this PAN NetworkSetup available to us ?
Run = Sys.findInterface( C->Device );
@@ -141,3 +141,3 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
if( Run && Run->IsUp ) {
- // this PAN connection is up
+ // this PAN NetworkSetup is up
Log(("%s acceptable but unavailable\n",
@@ -156,3 +156,3 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
if ( Grab ) {
- netNode()->connection()->assignInterface( Candidate );
+ netNode()->networkSetup()->assignInterface( Candidate );
}
@@ -114,3 +114,3 @@ bool BluetoothBNEPRun::hasFreePANConnection( bool Grab ) {
} else {
- // is this PAN connection connecting to a Peer
+ // is this PAN NetworkSetup connecting to a Peer
// we allow ?